@@ -3,7 +3,12 @@ from urllib3 import Retry
 from seldon_deploy_sdk.configuration import Configuration
 from seldon_deploy_sdk.rest import RESTClientObject
 
-from .base import Authenticator
+from .base import (
+    Authenticator,
+    AuthMethod,
+    _raise_auth_method_not_supported,
+    _soft_deprecate,
+)
 
 
 class SessionAuthenticator(Authenticator):
@@ -13,12 +18,21 @@ class SessionAuthenticator(Authenticator):
 
     def __init__(self, config: Configuration):
         super().__init__(config)
+
         self._client = RESTClientObject(config)
 
-    def authenticate(self, user: str, password: str) -> str:
+    @_soft_deprecate  # type: ignore
+    def authenticate(self, username: str = None, password: str = None) -> str:
         auth_path = self._get_auth_path()
-        session_cookie = self._submit_auth(auth_path, user, password)
-        return session_cookie
+        if self._config.auth_method == AuthMethod.PASSWORD_GRANT:
+            session_cookie = self._submit_auth(
+                auth_path,
+                username or self._config.username,
+                password or self._config.password,
+            )
+            return session_cookie
+
+        _raise_auth_method_not_supported(self._config.auth_method)
 
     def _get_auth_path(self) -> str:
         # Send unauthenticated request
